function T = ABCD_chain(varargin) % SRR: Edited 1/23/17
% Take vectors of areas and lengths of individual segments, and calculate
% total chain of ABCD matrices

% Inputs: 
% f = frequency in Hz
% A = length N vector of areas, left to right 
% L = length N-1 vector of segment lengths, left to right
% P (optional) = length N vector of perimeters, left to right (wall loss for 
% non-standard geometry; set to 0 for lossless wave propagation)

% Output:
% ABCD matrix 'T' for whole segment

if nargin == 3  
    f = varargin{1};
    A = varargin{2};
    L = varargin{3};
    P = 2*pi*sqrt(A/pi);
elseif nargin == 4
    f = varargin{1};
    A = varargin{2};
    L = varargin{3};
    P = varargin{4};
else
    disp('Wrong number of inputs!'); return
end

% initialize T matrix (identity matrix at each frequency)
T(1,1,:) = ones(1,length(f));
T(1,2,:) = zeros(1,length(f)); 
T(2,1,:) = zeros(1,length(f));
T(2,2,:) = ones(1,length(f)); 

for k1 = 1:length(L) % iterate over sections
        if A(k1)== A(k1+1) % uniform tube
            T_here = ABCD_cone_tube(f,A(k1),A(k1+1),L(k1),P(k1));
        elseif L(k1) == 0 % karal
            T_here = ABCD_karal(f,A(k1),A(k1+1));
        else % cone 
            d_left = 2*sqrt(A(k1)/pi); d_right = 2*sqrt(A(k1+1)/pi);
            % construct slices so diameter step size is 1% of smallest diameter
            num_slices = round(abs(d_left-d_right)/(0.01*min(d_left,d_right)));
            
            % diameter and perimeter will vary linearly for spherical wave
            % propagation in a cone
            delta_slice = (d_right-d_left)/num_slices;
            A_allPoints = ((d_left+[0:num_slices]*delta_slice)/2).^2;
            L_slice = L(k1)/num_slices;
            P_allPoints = P(k1)+[0:num_slices]*(P(k1+1)-P(k1))/num_slices;
            
            T_here(1,1,:) = ones(1,length(f)); T_here(1,2,:) = zeros(1,length(f)); 
            T_here(2,1,:) = zeros(1,length(f)); T_here(2,2,:) = ones(1,length(f)); 
            for k3 = 1:num_slices
                T_tmp = ABCD_cone_tube(f,A_allPoints(k3),A_allPoints(k3+1),L_slice,min(P_allPoints(k3:k3+1)));
                for k2 = 1:length(f)
                    T_here(:,:,k2) = T_tmp(:,:,k2)*T_here(:,:,k2);
                end
            end
        end
        
        % calculate chain of T matrices so far
        for k2 = 1:length(f)
           T(:,:,k2) = T_here(:,:,k2)*T(:,:,k2); % matrix multiplication 
        end
end
