function [ZL,H_PLdivPR] = calc_ZL(T,Zin) % SRR: Edited 1/23/17
% Calculate the input impedance of a transmission line described by T, with
% load ZL

% Inputs: 
% T = ABCD matrix describing transmission line
% Zin = input impedance
% NOTE: T and Zin must correspond to same frequencies

% Output:
% ZL = load impedance at far end
% H_PLdivPR (optional) = pressure (or voltage) transfer function Left/Right

% Z matrix method (e.g. Wikipedia): Zin = z11-z12*z21/(ZL+z22);
Z = ABCD_TtoZ(T);
ZL = squeeze(Z(1,2,:)).*squeeze(Z(2,1,:))./(squeeze(Z(1,1,:))-Zin) -squeeze(Z(2,2,:));

% P2 = -U2*ZL, thus P1/P2 = (A+B/ZL)
H_PLdivPR = (squeeze(T(1,1,:))+squeeze(T(1,2,:))./ZL);

