function [Zin,H_PRdivPL] = calc_Zin(T,ZL) % SRR: Edited 1/23/17
% Calculate the input impedance of a transmission line described by T, with
% load ZL

% Inputs: 
% T = ABCD matrix describing transmission line
% ZL = load impedance at far end
% NOTE: T and ZL must correspond to same frequencies

% Output:
% Zin = input impedance of line
% H_PRdivPL (optional) = pressure (or voltage) transfer function Right/Left

% P2 = -U2*ZL, thus P2/P1 = 1/(A+B/ZL)
H_PRdivPL = 1./(squeeze(T(1,1,:))+squeeze(T(1,2,:))./ZL);

% Z matrix method (e.g. Wikipedia): Zin = z11-z12*z21/(ZL+z22);
Z = ABCD_TtoZ(T);
Zin = squeeze(Z(1,1,:)) - squeeze(Z(1,2,:)).*squeeze(Z(2,1,:))./(ZL + squeeze(Z(2,2,:)));

