function T = calc_probeTip(varargin) % SRR: Edited 1/24/17
% Calculate T for the aluminum probe tip

% Inputs: 
% f = frequency in Hz

% Output:
% T = ABCD matrix for probe tip

addpath('bin')

if nargin == 0
    f = [200:10:10000];
    show_fig = 1;
elseif nargin == 1
    f = varargin{1};
    show_fig = 0;
end

L = [0.006531, 0.013266, 0];
d = [0.0075, 0.004, 0.004, 0.0075];
A = pi*(d/2).^2;

T = ABCD_chain(f,A,L);

if show_fig == 1
    A = squeeze(T(1,1,:));
    B = squeeze(T(1,2,:));
    C = squeeze(T(2,1,:));
    D = squeeze(T(2,2,:));
   
    figure('units','normalized','outerposition',[0.05 0.3 0.9 0.7]);
    
    % A
    subplot(241)
    plot(f/1000,abs(A));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|A|');
    subplot(242)
    plot(f/1000,unwrap(angle(A))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle A [rad/\pi]')
    % B
    subplot(243)
    plot(f/1000,abs(B));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|B|');
    subplot(244)
    plot(f/1000,unwrap(angle(B))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle B [rad/\pi]')
    % C
    subplot(245)
    plot(f/1000,abs(C));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|C|');
    subplot(246)
    plot(f/1000,unwrap(angle(C))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle C [rad/\pi]')
    % D
    subplot(247)
    plot(f/1000,abs(D));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|D|');
    subplot(248)
    plot(f/1000,unwrap(angle(D))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle D [rad/\pi]')
    
    
    Z = ABCD_TtoZ(T);
    
    z11 = squeeze(Z(1,1,:));
    z12 = squeeze(Z(1,2,:));
    z21 = squeeze(Z(2,1,:));
    z22 = squeeze(Z(2,2,:));
   
    figure('units','normalized','outerposition',[0.05 0.2 0.9 0.7]);
    
    % A
    subplot(241)
    plot(f/1000,abs(z11));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|z_{11}|');
    subplot(242)
    plot(f/1000,unwrap(angle(z11))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle z_{11} [rad/\pi]')
    % B
    subplot(243)
    plot(f/1000,abs(z12));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|z_{12}|');
    subplot(244)
    plot(f/1000,unwrap(angle(z12))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle z_{12} [rad/\pi]')
    % C
    subplot(245)
    plot(f/1000,abs(z21));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|z_{21}|');
    subplot(246)
    plot(f/1000,unwrap(angle(z21))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle z_{21} [rad/\pi]')
    % D
    subplot(247)
    plot(f/1000,abs(z22));
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('|z_{22}|');
    subplot(248)
    plot(f/1000,unwrap(angle(z22))/pi);
    set(gca,'xscale','log'); xlabel('Frequency [kHz]'); ylabel('\angle z_{22} [rad/\pi]')
    
end